# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class EditableText(Component):
    """An EditableText component.
EditableText appears as normal UI text but transforms into a text input field when the user focuses it.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- alwaysRenderInput (boolean; optional):
    EXPERIMENTAL FEATURE.  When True, this forces the component to
    always render an editable input (or textarea) both when the
    component is focussed and unfocussed, instead of the component's
    default behavior of switching between a text span and a text
    input upon interaction. This behavior can help in certain
    applications where, for example,  a custom right-click context
    menu is used to supply clipboard  copy and paste functionality.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- confirmOnEnterKey (boolean; optional):
    If True and in multiline mode, the enter key will trigger
    onConfirm  and mod+enter will insert a newline. If False, the key
    bindings are  inverted such that enter adds a newline.

- defaultValue (string; optional):
    Default text value of uncontrolled input.

- disabled (boolean; optional):
    Whether the text can be edited.

- intent (string; optional):
    Visual intent color to apply to element.

- lastOnCancel (string; optional):
    Callback invoked when user cancels input with the esc key.
    Receives last confirmed value.

- maxLength (number; optional):
    Maximum number of characters allowed. Unlimited by default.

- maxLines (number; optional):
    Maximum number of lines before scrolling begins, when multiline.

- minLines (number; optional):
    Minimum number of lines (essentially minimum height), when
    multiline.

- minWidth (number; optional):
    Minimum width in pixels of the input, when not multiline.

- multiline (boolean; optional):
    Whether the component supports multiple lines of text.  This prop
    should not be changed during the component's lifetime.

- n_changes (number; default 0):
    Callback invoked when user changes input in any way.

- n_confirms (number; default 0):
    Callback invoked when user confirms value with enter key or by
    blurring input.

- n_edits (number; default 0):
    Callback invoked after the user enters edit mode.

- placeholder (string; optional):
    Placeholder text when there is no value.

- selectAllOnFocus (boolean; optional):
    Whether the entire text field should be selected on focus. If
    False,  the cursor is placed at the end of the text. This prop is
    ignored on  inputs with type other then text, search, url, tel and
    password.  See
    https://html.spec.whatwg.org/multipage/input.html#do-not-apply for
    details.

- style (dict; optional):
    CSS properties to apply to the root element.

- type (string; optional):
    The type of input that should be shown, when not multiline.

- value (string; optional):
    Text value of controlled input."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'EditableText'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, alwaysRenderInput=Component.UNDEFINED, className=Component.UNDEFINED, confirmOnEnterKey=Component.UNDEFINED, defaultValue=Component.UNDEFINED, disabled=Component.UNDEFINED, intent=Component.UNDEFINED, maxLength=Component.UNDEFINED, maxLines=Component.UNDEFINED, minLines=Component.UNDEFINED, minWidth=Component.UNDEFINED, multiline=Component.UNDEFINED, lastOnCancel=Component.UNDEFINED, n_changes=Component.UNDEFINED, n_confirms=Component.UNDEFINED, n_edits=Component.UNDEFINED, placeholder=Component.UNDEFINED, selectAllOnFocus=Component.UNDEFINED, style=Component.UNDEFINED, type=Component.UNDEFINED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'alwaysRenderInput', 'className', 'confirmOnEnterKey', 'defaultValue', 'disabled', 'intent', 'lastOnCancel', 'maxLength', 'maxLines', 'minLines', 'minWidth', 'multiline', 'n_changes', 'n_confirms', 'n_edits', 'placeholder', 'selectAllOnFocus', 'style', 'type', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'alwaysRenderInput', 'className', 'confirmOnEnterKey', 'defaultValue', 'disabled', 'intent', 'lastOnCancel', 'maxLength', 'maxLines', 'minLines', 'minWidth', 'multiline', 'n_changes', 'n_confirms', 'n_edits', 'placeholder', 'selectAllOnFocus', 'style', 'type', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(EditableText, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class TimePicker(Component):
    """A TimePicker component.
A TimePicker allows the user to specify a time.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- autoFocus (boolean; optional):
    Whether to focus the first input when it opens initially.

- defaultValue (string; optional):
    Initial time the TimePicker will display. This should not be set
    if value is set.

- disabled (boolean; optional):
    Whether the time picker is non-interactive.

- maxTime (string; optional):
    The latest time the user can select. The year, month, and day
    parts of the Date object are ignored.  While the maxTime will be
    later than the minTime in the basic case, it is also allowed to be
    earlier  than the minTime. This is useful, for example, to express
    a time range that extends before and after midnight.  If the
    maxTime and minTime are equal, then the valid time range is
    constrained to only that one value.

- minTime (string; optional):
    The earliest time the user can select. The year, month, and day
    parts of the Date object are ignored. While the  minTime will be
    earlier than the maxTime in the basic case, it is also allowed to
    be later than the maxTime. This  is useful, for example, to
    express a time range that extends before and after midnight. If
    the maxTime and minTime  are equal, then the valid time range is
    constrained to only that one value.

- precision (string; optional):
    The precision of time the user can set.

- selectAllOnFocus (boolean; optional):
    Whether all the text in each input should be selected on focus.

- showArrowButtons (boolean; optional):
    Whether to show arrows buttons for changing the time.

- style (dict; optional):
    CSS properties to apply to the root element.

- useAmPm (boolean; optional):
    Whether to use a 12 hour format with an AM/PM dropdown.

- value (string; optional):
    The currently set time."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'TimePicker'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, autoFocus=Component.UNDEFINED, defaultValue=Component.UNDEFINED, disabled=Component.UNDEFINED, maxTime=Component.UNDEFINED, minTime=Component.UNDEFINED, precision=Component.UNDEFINED, selectAllOnFocus=Component.UNDEFINED, showArrowButtons=Component.UNDEFINED, style=Component.UNDEFINED, useAmPm=Component.UNDEFINED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'autoFocus', 'defaultValue', 'disabled', 'maxTime', 'minTime', 'precision', 'selectAllOnFocus', 'showArrowButtons', 'style', 'useAmPm', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'autoFocus', 'defaultValue', 'disabled', 'maxTime', 'minTime', 'precision', 'selectAllOnFocus', 'showArrowButtons', 'style', 'useAmPm', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(TimePicker, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Handle(Component):
    """A Handle component.
Handles for a MultiSlider.

Keyword arguments:

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- intentAfter (string; optional):
    Intent for the track segment immediately after this handle, taking
    priority over intentBefore.

- intentBefore (string; optional):
    Intent for the track segment immediately before this handle.

- interactionKind (a value equal to: 'lock', 'push'; optional):
    How this handle interacts with other handles.

- labelStepSize (number; optional):
    Increment between successive labels. Must be greater than zero.

- style (dict; optional):
    CSS properties to apply to the root element.

- trackStyleAfter (dict; optional):
    Style to use for the track segment immediately after this handle,
    taking priority over trackStyleBefore.

- trackStyleBefore (dict; optional):
    Style to use for the track segment immediately before this handle.

- type (a value equal to: 'full', 'start', 'end'; optional):
    Handle appearance type.

- value (number; required):
    Numeric value of this handle."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Handle'
    @_explicitize_args
    def __init__(self, className=Component.UNDEFINED, intentAfter=Component.UNDEFINED, intentBefore=Component.UNDEFINED, interactionKind=Component.UNDEFINED, labelStepSize=Component.UNDEFINED, style=Component.UNDEFINED, trackStyleAfter=Component.UNDEFINED, trackStyleBefore=Component.UNDEFINED, type=Component.UNDEFINED, value=Component.REQUIRED, **kwargs):
        self._prop_names = ['className', 'intentAfter', 'intentBefore', 'interactionKind', 'labelStepSize', 'style', 'trackStyleAfter', 'trackStyleBefore', 'type', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['className', 'intentAfter', 'intentBefore', 'interactionKind', 'labelStepSize', 'style', 'trackStyleAfter', 'trackStyleBefore', 'type', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['value']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Handle, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DatePicker(Component):
    """A DatePicker component.
DatePicker renders a UI to choose a single date and (optionally) a time of day.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- canClearSelection (boolean; optional):
    Allows the user to clear the selection by clicking the currently
    selected day. If disabled, the \"Clear\"  Button in the Actions
    Bar will also be disabled.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- clearButtonText (string; optional):
    Text for the reset button in the action bar.

- date (string; optional):
    The currently selected day.

- defaultValue (string; optional):
    Initial day the calendar will display as selected. This should not
    be set if value is set.

- footerElement (a list of or a singular dash component, string or number; optional):
    An additional element to show below the date picker.

- highlightCurrentDay (boolean; optional):
    Whether the current day should be highlighted in the calendar.

- initialMonth (string; optional):
    The initial month the calendar displays.

- maxDate (string; optional):
    The latest date the user can select.

- minDate (string; optional):
    The earliest date the user can select.

- reverseMonthAndYearMenus (boolean; optional):
    If True, the month menu will appear to the left of the year menu.
    Otherwise, the month menu will apear to  the right of the year
    menu.

- selectedShortcutIndex (number; optional):
    The currently selected shortcut. If this prop is provided, the
    component acts in a controlled manner.

- shortcuts (boolean; optional):
    Whether shortcuts to quickly select a date are displayed or not.
    If True, preset shortcuts will be displayed. If False,  no
    shortcuts will be displayed.

- showActionsBar (boolean; optional):
    Whether the bottom bar displaying \"Today\" and \"Clear\" buttons
    should be shown.

- showOutsideDays (boolean; optional):
    Whether to show in muted format the days not belonging to the
    current month.

- showTimeArrowButtons (boolean; optional):
    Whether arrows for selecting the time should be shown.

- showWeekNumber (boolean; optional):
    Whether to show week numbers.

- style (dict; optional):
    CSS properties to apply to the root element.

- timePrecision (string; optional):
    The precision of time selection that accompanies the calendar.
    Passing a TimePrecision value shows a TimePicker below the
    calendar. Time is preserved across date changes. Either 'minute',
    'second', 'millisecond'.

- todayButtonText (string; optional):
    Text for the today button in the action bar.

- useAmPm (boolean; optional):
    Whether the time should be displayed as AM/PM."""
    _children_props = ['footerElement']
    _base_nodes = ['footerElement', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'DatePicker'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, canClearSelection=Component.UNDEFINED, className=Component.UNDEFINED, clearButtonText=Component.UNDEFINED, date=Component.UNDEFINED, defaultValue=Component.UNDEFINED, footerElement=Component.UNDEFINED, highlightCurrentDay=Component.UNDEFINED, initialMonth=Component.UNDEFINED, maxDate=Component.UNDEFINED, minDate=Component.UNDEFINED, reverseMonthAndYearMenus=Component.UNDEFINED, selectedShortcutIndex=Component.UNDEFINED, shortcuts=Component.UNDEFINED, showActionsBar=Component.UNDEFINED, showTimeArrowButtons=Component.UNDEFINED, showOutsideDays=Component.UNDEFINED, showWeekNumber=Component.UNDEFINED, style=Component.UNDEFINED, timePrecision=Component.UNDEFINED, todayButtonText=Component.UNDEFINED, useAmPm=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'canClearSelection', 'className', 'clearButtonText', 'date', 'defaultValue', 'footerElement', 'highlightCurrentDay', 'initialMonth', 'maxDate', 'minDate', 'reverseMonthAndYearMenus', 'selectedShortcutIndex', 'shortcuts', 'showActionsBar', 'showOutsideDays', 'showTimeArrowButtons', 'showWeekNumber', 'style', 'timePrecision', 'todayButtonText', 'useAmPm']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'canClearSelection', 'className', 'clearButtonText', 'date', 'defaultValue', 'footerElement', 'highlightCurrentDay', 'initialMonth', 'maxDate', 'minDate', 'reverseMonthAndYearMenus', 'selectedShortcutIndex', 'shortcuts', 'showActionsBar', 'showOutsideDays', 'showTimeArrowButtons', 'showWeekNumber', 'style', 'timePrecision', 'todayButtonText', 'useAmPm']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(DatePicker, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Icon(Component):
    """An Icon component.
Use the <Icon> component to easily render SVG icons in React

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Buttons in this group.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- color (string; optional):
    Color of icon. This is used as the fill attribute on the <svg>
    image so  it will override any CSS color property, including that
    set by intent.  If this prop is omitted, icon color is inherited
    from surrounding text.

- htmlTitle (string; optional):
    String for the title attribute on the rendered element, which will
    appear  on hover as a native browser tooltip.

- icon (string; required):
    Name of a Blueprint UI icon (or an icon element) to render on the
    left side.  If this prop is omitted or undefined, the intent prop
    will determine  a default icon. If this prop is explicitly None,
    no icon will be displayed  (regardless of intent).

- intent (string; optional):
    Visual intent color to apply to background, title, and icon.
    Defining this  prop also applies a default icon, if the icon prop
    is omitted.

- n_clicks (number; default 0):
    An integer that represents the time (in ms since 1970) at which
    n_clicks changed. This can be used to tell which button was
    changed most recently.

- size (number; optional):
    Size of the icon, in pixels. Blueprint contains 16px and 20px SVG
    icon images,  and chooses the appropriate resolution based on this
    prop.

- style (dict; optional):
    CSS properties to apply to the root element.

- tagName (optional):
    HTML tag to use for the rendered element.

- title (string; optional):
    Description string. This string does not appear in normal
    browsers, but it  increases accessibility. For instance, screen
    readers will use it for aural  feedback. If this value is Noneish,
    False, or an empty string, the component  will assume that the
    icon is decorative and aria-hidden=\"True\" will be applied. See:
    https://www.w3.org/WAI/tutorials/images/decorative/."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Icon'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, color=Component.UNDEFINED, htmlTitle=Component.UNDEFINED, icon=Component.REQUIRED, n_clicks=Component.UNDEFINED, intent=Component.UNDEFINED, size=Component.UNDEFINED, style=Component.UNDEFINED, tagName=Component.UNDEFINED, title=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'color', 'htmlTitle', 'icon', 'intent', 'n_clicks', 'size', 'style', 'tagName', 'title']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'color', 'htmlTitle', 'icon', 'intent', 'n_clicks', 'size', 'style', 'tagName', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['icon']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Icon, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class FileInput(Component):
    """A FileInput component.
File input component.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- buttonText (string; optional):
    The button text.

- content (string; optional):
    Content of the file as base64 string.

- disabled (boolean; optional):
    Whether the file input is non-interactive. Setting this to True
    will automatically disable the child input too.

- filename (string; optional):
    Filename of the file.

- fill (boolean; optional):
    Whether the file input should take up the full width of its
    container.

- hasSelection (boolean; optional):
    Whether the user has made a selection in the input. This will
    affect  the component's text styling. Make sure to set a non-empty
    value for  the text prop as well.

- large (boolean; optional):
    Whether the file input should appear with large styling.

- small (boolean; optional):
    Whether the file input should appear with small styling.

- style (dict; optional):
    CSS properties to apply to the root element.

- text (string; optional):
    The text to display."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'FileInput'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, buttonText=Component.UNDEFINED, content=Component.UNDEFINED, filename=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, hasSelection=Component.UNDEFINED, large=Component.UNDEFINED, small=Component.UNDEFINED, style=Component.UNDEFINED, text=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'buttonText', 'content', 'disabled', 'filename', 'fill', 'hasSelection', 'large', 'small', 'style', 'text']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'buttonText', 'content', 'disabled', 'filename', 'fill', 'hasSelection', 'large', 'small', 'style', 'text']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(FileInput, self).__init__(**args)



import dash
from dash import html, Output, Input

import dash_blueprint_components as dbpc


def test_fcsc001_programmatic_control(dash_duo):
    print("Running my test")
    app = dash.Dash(__name__)

    options = [
        {
            "label": "List",
            "value": "list",
        },
        {
            "label": "Grid",
            "value": "grid",
        },
        {
            "label": "Gallery",
            "value": "gallery",
        },
    ]

    default_value = "list"

    def get_label(value: str) -> str:
        for option in options:
            if option["value"] == value:
                return option["label"]
        return ""

    app.layout = html.Div(
        children=[
            dbpc.SegmentedControl(
                id="segmented-control",
                options=options,
                value=default_value,
            ),
            dbpc.SegmentedControl(
                id="segmented-control_2",
                options=options,
                disabled=True,
            ),
        ],
    )

    @app.callback(
        Output("segmented-control_2", "value"),
        Input("segmented-control", "value"),
    )
    def update_segmented_control_2(value):
        return value

    dash_duo.start_server(app)

    # Assert that the button corresponding to the default value is in selected mode,
    # i.e. the value property has been properly passed to the underlying component
    dash_duo.wait_for_text_to_equal(
        "#segmented-control_2 > .bp5-button:not(.bp5-minimal)", get_label(default_value)
    )
    # Assert that the second control correctly responds to programmatic changes to
    # its value property, i.e. the selected button is shown. (If not, the
    # .bp5-button:not(.bp5-minimal) selector will not match any elements)
    dash_duo.wait_for_text_to_equal(
        "#segmented-control_2 > .bp5-button:not(.bp5-minimal)", get_label(default_value)
    )

    control_1_buttons = dash_duo.find_elements("#segmented-control > .bp5-button")
    # The value of control 2 should change when the value of control 1 changes
    control_1_buttons[1].click()
    dash_duo.wait_for_text_to_equal(
        "#segmented-control_2 > .bp5-button:not(.bp5-minimal)", options[1]["label"]
    )

    control_2_buttons = dash_duo.find_elements("#segmented-control_2 > .bp5-button")
    # Clicking on the buttons of control 2 should not change the value of control 2 as
    # it is disabled
    control_2_buttons[2].click()
    assert (
        dash_duo.find_element(
            "#segmented-control_2 > .bp5-button:not(.bp5-minimal)"
        ).text
        == options[1]["label"]
    ), "Segmented control 2 is disabled, and selecting other options should not be possible."



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Navbar(Component):
    """A Navbar component.
Navbars present useful navigation controls at the top of an application.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Content of the Navbar.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- fixedToTop (boolean; optional):
    Whether this navbar should be fixed to the top of the viewport
    (using CSS position: fixed).

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Navbar'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, fixedToTop=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'fixedToTop', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'fixedToTop', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Navbar, self).__init__(children=children, **args)



from .AnchorButton import AnchorButton
from .Breadcrumb import Breadcrumb
from .Button import Button
from .ButtonGroup import ButtonGroup
from .Callout import Callout
from .Card import Card
from .CardList import CardList
from .Collapse import Collapse
from .CompoundTag import CompoundTag
from .Divider import Divider
from .EditableText import EditableText
from .EntityTitle import EntityTitle
from .Icon import Icon
from .ProgressBar import ProgressBar
from .Section import Section
from .SectionCard import SectionCard
from .Spinner import Spinner
from .Tag import Tag
from .Text import Text
from .Tree import Tree
from .CheckboxCard import CheckboxCard
from .RadioCard import RadioCard
from .SwitchCard import SwitchCard
from .Menu import Menu
from .MenuDivider import MenuDivider
from .MenuItem import MenuItem
from .Navbar import Navbar
from .NavbarDivider import NavbarDivider
from .NavbarGroup import NavbarGroup
from .NavbarHeading import NavbarHeading
from .SideBar import SideBar
from .Tab import Tab
from .Tabs import Tabs
from .DateInput import DateInput
from .DatePicker import DatePicker
from .DateRangeInput import DateRangeInput
from .DateRangePicker import DateRangePicker
from .TimePicker import TimePicker
from .TimezoneSelect import TimezoneSelect
from .Checkbox import Checkbox
from .ControlGroup import ControlGroup
from .FormGroup import FormGroup
from .HTMLSelect import HTMLSelect
from .Radio import Radio
from .RadioGroup import RadioGroup
from .SegmentedControl import SegmentedControl
from .Switch import Switch
from .Handle import Handle
from .MultiSlider import MultiSlider
from .RangeSlider import RangeSlider
from .Slider import Slider
from .FileInput import FileInput
from .InputGroup import InputGroup
from .NumericInput import NumericInput
from .TagInput import TagInput
from .TextArea import TextArea
from .Alert import Alert
from .ContextMenu import ContextMenu
from .Drawer import Drawer
from .Popover import Popover
from .Tooltip import Tooltip
from .Dialog import Dialog
from .DialogBody import DialogBody
from .DialogFooter import DialogFooter
from .DialogStep import DialogStep
from .MultistepDialog import MultistepDialog
from .OverlayToaster import OverlayToaster
from .Toast import Toast
from .MultiSelect import MultiSelect
from .Omnibar import Omnibar
from .Select import Select
from .Suggest import Suggest

__all__ = [
    "AnchorButton",
    "Breadcrumb",
    "Button",
    "ButtonGroup",
    "Callout",
    "Card",
    "CardList",
    "Collapse",
    "CompoundTag",
    "Divider",
    "EditableText",
    "EntityTitle",
    "Icon",
    "ProgressBar",
    "Section",
    "SectionCard",
    "Spinner",
    "Tag",
    "Text",
    "Tree",
    "CheckboxCard",
    "RadioCard",
    "SwitchCard",
    "Menu",
    "MenuDivider",
    "MenuItem",
    "Navbar",
    "NavbarDivider",
    "NavbarGroup",
    "NavbarHeading",
    "SideBar",
    "Tab",
    "Tabs",
    "DateInput",
    "DatePicker",
    "DateRangeInput",
    "DateRangePicker",
    "TimePicker",
    "TimezoneSelect",
    "Checkbox",
    "ControlGroup",
    "FormGroup",
    "HTMLSelect",
    "Radio",
    "RadioGroup",
    "SegmentedControl",
    "Switch",
    "Handle",
    "MultiSlider",
    "RangeSlider",
    "Slider",
    "FileInput",
    "InputGroup",
    "NumericInput",
    "TagInput",
    "TextArea",
    "Alert",
    "ContextMenu",
    "Drawer",
    "Popover",
    "Tooltip",
    "Dialog",
    "DialogBody",
    "DialogFooter",
    "DialogStep",
    "MultistepDialog",
    "OverlayToaster",
    "Toast",
    "MultiSelect",
    "Omnibar",
    "Select",
    "Suggest"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DateRangeInput(Component):
    """A DateRangeInput component.
The DateRangeInput component is ControlGroup composed of two InputGroups. It shows a 
DateRangePicker in a Popover on focus.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- allowSingleDayRange (boolean; optional):
    Whether the start and end dates of the range can be the same day.
    If True, clicking a selected date will  create a one-day range. If
    False, clicking a selected date will clear the selection.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- closeOnSelection (string; optional):
    Whether the calendar popover should close when a date is selected.

- contiguousCalendarMonths (boolean; optional):
    Whether displayed months in the calendar are contiguous. If False,
    each side of the calendar can move independently  to
    non-contiguous months.

- dateFnsFormat (string; optional):
    date-fns format string used to format & parse date strings.

- defaultValue (list; optional):
    Initial day the calendar will display as selected. This should not
    be set if value is set.

- disabled (boolean; optional):
    Whether the text inputs are non-interactive.

- fill (boolean; optional):
    Whether the component should take up the full width of its
    container.

- footerElement (a list of or a singular dash component, string or number; optional):
    An additional element to show below the date picker.

- highlightCurrentDay (boolean; optional):
    Whether the current day should be highlighted in the calendar.

- initialMonth (string; optional):
    The initial month the calendar displays.

- invalidDateMessage (string; optional):
    The error message to display when the date selected is invalid.

- locale (string; optional):
    The locale name, which is passed to the functions in localeUtils
    (and formatDate and parseDate if supported).

- outOfRangeMessage (string; optional):
    The error message to display when the date selected is out of
    range.

- overlappingDatesMessage (string; optional):
    The error message to display when the selected dates overlap. This
    can only happen when typing dates in the input field.

- placeholder (string; optional):
    Placeholder text to display in empty input fields. Recommended
    practice is to indicate the expected date format.

- range (list; optional):
    The currently selected range.

- reverseMonthAndYearMenus (boolean; optional):
    If True, the month menu will appear to the left of the year menu.
    Otherwise, the month menu will apear to  the right of the year
    menu.

- selectAllOnFocus (boolean; optional):
    Whether the entire text field should be selected on focus.

- selectedShortcutIndex (number; optional):
    The currently selected shortcut.

- shortcuts (boolean; optional):
    Whether shortcuts to quickly select a date are displayed or not.
    If True, preset shortcuts will be displayed. If False,  no
    shortcuts will be displayed.

- showTimeArrowButtons (boolean; optional):
    Whether arrows for selecting the time should be shown.

- singleMonthOnly (boolean; optional):
    Whether to show only a single month calendar.

- style (dict; optional):
    CSS properties to apply to the root element.

- timePrecision (string; optional):
    The precision of time selection that accompanies the calendar.
    Passing a TimePrecision value shows a TimePicker below the
    calendar. Time is preserved across date changes. Either 'minute',
    'second', 'millisecond'.

- useAmPm (boolean; optional):
    Whether the time should be displayed as AM/PM."""
    _children_props = ['footerElement']
    _base_nodes = ['footerElement', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'DateRangeInput'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, allowSingleDayRange=Component.UNDEFINED, closeOnSelection=Component.UNDEFINED, contiguousCalendarMonths=Component.UNDEFINED, className=Component.UNDEFINED, dateFnsFormat=Component.UNDEFINED, defaultValue=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, footerElement=Component.UNDEFINED, highlightCurrentDay=Component.UNDEFINED, initialMonth=Component.UNDEFINED, invalidDateMessage=Component.UNDEFINED, locale=Component.UNDEFINED, maxDate=Component.UNDEFINED, minDate=Component.UNDEFINED, outOfRangeMessage=Component.UNDEFINED, overlappingDatesMessage=Component.UNDEFINED, placeholder=Component.UNDEFINED, range=Component.UNDEFINED, reverseMonthAndYearMenus=Component.UNDEFINED, selectAllOnFocus=Component.UNDEFINED, selectedShortcutIndex=Component.UNDEFINED, shortcuts=Component.UNDEFINED, singleMonthOnly=Component.UNDEFINED, showTimeArrowButtons=Component.UNDEFINED, style=Component.UNDEFINED, timePrecision=Component.UNDEFINED, useAmPm=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'allowSingleDayRange', 'className', 'closeOnSelection', 'contiguousCalendarMonths', 'dateFnsFormat', 'defaultValue', 'disabled', 'fill', 'footerElement', 'highlightCurrentDay', 'initialMonth', 'invalidDateMessage', 'locale', 'outOfRangeMessage', 'overlappingDatesMessage', 'placeholder', 'range', 'reverseMonthAndYearMenus', 'selectAllOnFocus', 'selectedShortcutIndex', 'shortcuts', 'showTimeArrowButtons', 'singleMonthOnly', 'style', 'timePrecision', 'useAmPm']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'allowSingleDayRange', 'className', 'closeOnSelection', 'contiguousCalendarMonths', 'dateFnsFormat', 'defaultValue', 'disabled', 'fill', 'footerElement', 'highlightCurrentDay', 'initialMonth', 'invalidDateMessage', 'locale', 'outOfRangeMessage', 'overlappingDatesMessage', 'placeholder', 'range', 'reverseMonthAndYearMenus', 'selectAllOnFocus', 'selectedShortcutIndex', 'shortcuts', 'showTimeArrowButtons', 'singleMonthOnly', 'style', 'timePrecision', 'useAmPm']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(DateRangeInput, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class SegmentedControl(Component):
    """A SegmentedControl component.
A SegmentedControl is a linear collection of buttons which allows a user to choose an option from multiple choices,
 similar to a Radio group. Compared to the ButtonGroup component, SegmentedControl has affordances to signify a
 selection UI and a reduced visual weight which is appropriate for forms.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- disabled (boolean; default False):
    If True, the option buttons are non-interactive. The value can
    still controllable via callback if disabled is True. Default is
    False.

- fill (boolean; optional):
    Whether the control group should take up the full width of its
    container.

- inline (boolean; optional):
    Whether the control should appear as an inline element.

- intent (string; optional):
    Visual intent to apply to the selected value.

- large (boolean; optional):
    Whether this control should use large buttons.

- options (list; optional):
    List of available options.

- small (boolean; optional):
    Whether this control should use small buttons.

- style (dict; optional):
    CSS properties to apply to the root element.

- value (string; optional):
    Selected value. When a value is given to this prop, the
    defaultValue is ignored. When using the value of this component as
    a state or input in a callback, use this property instead of
    defaultValue."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'SegmentedControl'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, inline=Component.UNDEFINED, intent=Component.UNDEFINED, large=Component.UNDEFINED, options=Component.UNDEFINED, small=Component.UNDEFINED, style=Component.UNDEFINED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'disabled', 'fill', 'inline', 'intent', 'large', 'options', 'small', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'disabled', 'fill', 'inline', 'intent', 'large', 'options', 'small', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(SegmentedControl, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class FormGroup(Component):
    """A FormGroup component.
Form groups support more complex form controls than simple labels, such as control 
groups or NumericInput. They also support additional helper text to aid with user navigation.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Group contents.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- contentClassName (string; optional):
    A space-delimited list of class names to pass along to the
    Classes.FORM_CONTENT element that contains children.

- disabled (boolean; optional):
    Whether form group should appear as non-interactive. Remember that
    input  elements must be disabled separately.

- helperText (a list of or a singular dash component, string or number; optional):
    Optional helper text. The given content will be wrapped in
    Classes.FORM_HELPER_TEXT and displayed beneath children. Helper
    text color  is determined by the intent.

- inline (boolean; optional):
    Whether to render the label and children on a single line.

- intent (string; optional):
    Visual intent color to apply to background, title, and icon.
    Defining this  prop also applies a default icon, if the icon prop
    is omitted.

- label (a list of or a singular dash component, string or number; optional):
    Label of this form group.

- labelFor (string; optional):
    id attribute of the labelable form element that this FormGroup
    controls,  used as <label for> attribute.

- labelInfo (a list of or a singular dash component, string or number; optional):
    Optional secondary text that appears after the label.

- style (dict; optional):
    CSS properties to apply to the root element.

- subLabel (a list of or a singular dash component, string or number; optional):
    Optional text for label. The given content will be wrapped in
    Classes.FORM_GROUP_SUB_LABEL and displayed beneath label. The text
    color is  determined by the intent."""
    _children_props = ['helperText', 'label', 'labelInfo', 'subLabel']
    _base_nodes = ['helperText', 'label', 'labelInfo', 'subLabel', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'FormGroup'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, contentClassName=Component.UNDEFINED, disabled=Component.UNDEFINED, helperText=Component.UNDEFINED, inline=Component.UNDEFINED, intent=Component.UNDEFINED, label=Component.UNDEFINED, labelFor=Component.UNDEFINED, labelInfo=Component.UNDEFINED, style=Component.UNDEFINED, subLabel=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'contentClassName', 'disabled', 'helperText', 'inline', 'intent', 'label', 'labelFor', 'labelInfo', 'style', 'subLabel']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'contentClassName', 'disabled', 'helperText', 'inline', 'intent', 'label', 'labelFor', 'labelInfo', 'style', 'subLabel']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(FormGroup, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class CardList(Component):
    """A CardList component.
CardList is a lightweight wrapper around the Card component. It can be 
used to visually group together cards in a list without any excess visual 
weight around or between them.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    list of cards.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- bordered (boolean; optional):
    Whether this container element should have a visual border. Set
    this to False to remove  elevation and border radius styles, which
    allows this element to be a child of another  bordered container
    element without padding (like SectionCard). Note that this also
    sets a  1px margin in dark theme to account for inset box shadows
    in that theme used across the  design system. Be sure to test your
    UI in both light and dark theme if you modify this prop value.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- compact (boolean; optional):
    Whether this component should use compact styles with reduced
    visual padding. Note that this prop  affects styling for all Cards
    within this CardList and you do not need to set the compact prop
    individually on those child Cards.

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'CardList'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, bordered=Component.UNDEFINED, className=Component.UNDEFINED, compact=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'bordered', 'className', 'compact', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'bordered', 'className', 'compact', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(CardList, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Collapse(Component):
    """A Collapse component.
The Collapse element shows and hides content with a built-in slide in/out animation. 
You might use this to create a panel of settings for your application, with sub-sections 
that can be expanded and collapsed.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Contents to collapse.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- component (optional):
    Component to render as the root element. Useful when rendering a
    Collapse inside a <table>, for instance.

- isOpen (boolean; optional):
    Whether the component is open or closed.

- keepChildrenMounted (boolean; optional):
    Whether the child components will remain mounted when the Collapse
    is  closed. Setting to True may improve performance by avoiding
    re-mounting  children.

- style (dict; optional):
    CSS properties to apply to the root element.

- transitionDuration (number; optional):
    The length of time the transition takes, in milliseconds. This
    must  match the duration of the animation in CSS. Only set this
    prop if you  override Blueprint's default transitions with new
    transitions of a  different length."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Collapse'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, component=Component.UNDEFINED, isOpen=Component.UNDEFINED, keepChildrenMounted=Component.UNDEFINED, style=Component.UNDEFINED, transitionDuration=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'component', 'isOpen', 'keepChildrenMounted', 'style', 'transitionDuration']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'component', 'isOpen', 'keepChildrenMounted', 'style', 'transitionDuration']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Collapse, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Switch(Component):
    """A Switch component.
Switch is a form control for toggling between boolean states. It is similar to Checkbox, 
but presents a more skeuomorphic appearance that mimics a physical switch.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Label for the control.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- alignIndicator (string; optional):
    Alignment of the indicator within container.

- checked (boolean; optional):
    Whether the control is checked.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- defaultChecked (boolean; optional):
    Label for the control.

- disabled (boolean; optional):
    Whether the control is non-interactive.

- inline (boolean; optional):
    Whether the control should appear as an inline element.

- innerLabel (string; optional):
    Text to display inside the switch indicator when unchecked.

- innerLabelChecked (string; optional):
    Text to display inside the switch indicator when checked.  If
    innerLabel is provided and this prop is omitted, then  innerLabel
    will be used for both states.

- label (string; optional):
    Text label for the control.

- labelElement (a list of or a singular dash component, string or number; optional):
    Element label for the control.

- large (boolean; optional):
    Whether this control should use large styles.

- style (dict; optional):
    CSS properties to apply to the root element.

- tagName (string; optional):
    Name of the HTML tag that wraps the checkbox. By default a
    <label> is used, which effectively enlarges the click target  to
    include all of its children. Supply a different tag name if  this
    behavior is undesirable or you're listening to click  events from
    a parent element (as the label can register  duplicate clicks)."""
    _children_props = ['labelElement']
    _base_nodes = ['labelElement', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Switch'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, alignIndicator=Component.UNDEFINED, checked=Component.UNDEFINED, defaultChecked=Component.UNDEFINED, disabled=Component.UNDEFINED, inline=Component.UNDEFINED, innerLabel=Component.UNDEFINED, innerLabelChecked=Component.UNDEFINED, label=Component.UNDEFINED, labelElement=Component.UNDEFINED, large=Component.UNDEFINED, style=Component.UNDEFINED, tagName=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'alignIndicator', 'checked', 'className', 'defaultChecked', 'disabled', 'inline', 'innerLabel', 'innerLabelChecked', 'label', 'labelElement', 'large', 'style', 'tagName']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'alignIndicator', 'checked', 'className', 'defaultChecked', 'disabled', 'inline', 'innerLabel', 'innerLabelChecked', 'label', 'labelElement', 'large', 'style', 'tagName']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Switch, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Drawer(Component):
    """A Drawer component.
Drawers overlay content over existing parts of the UI and are anchored to the edge of the screen.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Drawer contents.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- autoFocus (boolean; optional):
    Whether the overlay should acquire application focus when it first
    opens.

- backdropClassName (string; optional):
    CSS class names to apply to backdrop element.

- canEscapeKeyClose (boolean; optional):
    Whether pressing the esc key should invoke onClose.

- canOutsideClickClose (boolean; optional):
    Whether clicking outside the overlay element (either on backdrop
    when present or on document)  should invoke onClose.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- enforceFocus (boolean; optional):
    Whether the overlay should prevent focus from leaving itself. That
    is, if the user attempts to  focus an element outside the overlay
    and this prop is enabled, then the overlay will immediately  bring
    focus back to itself. If you are nesting overlay components,
    either disable this prop on the  \"outermost\" overlays or mark
    the nested ones usePortal={False}.

- hasBackdrop (boolean; optional):
    Whether a container-spanning backdrop element should be rendered
    behind the contents. When False, users  will be able to scroll
    through and interact with overlaid content.

- icon (string; optional):
    Name of a Blueprint UI icon to display on the left side.

- isCloseButtonShown (boolean; optional):
    Whether to show the close button in the dialog's header. Note that
    the header will only be  rendered if title is provided.

- isOpen (boolean; default False):
    Toggles the visibility of the alert.

- lazy (boolean; optional):
    If True and usePortal={True}, the Portal containing the children
    is created and attached to the  DOM when the overlay is opened for
    the first time; otherwise this happens when the component mounts.
    Lazy mounting provides noticeable performance improvements if you
    have lots of overlays at once,  such as on each row of a table.

- portalClassName (string; optional):
    Space-delimited string of class names applied to the Portal
    element if usePortal={True}.

- portalContainer (a list of or a singular dash component, string or number; optional):
    The container element into which the overlay renders its contents,
    when usePortal is True. This prop is  ignored if usePortal is
    False.

- position (string; optional):
    Position of a drawer. All angled positions will be casted into
    pure positions (TOP, BOTTOM, LEFT or RIGHT).

- shouldReturnFocusOnClose (boolean; optional):
    Whether the application should return focus to the last active
    element in the document after this overlay  closes.

- size (number | a value equal to: 'small', 'standard', 'large'; optional):
    CSS size of the drawer. This sets width if horizontal position
    (default) and height otherwise. Constants are available for common
    sizes:   DrawerSize.SMALL = 360px   DrawerSize.STANDARD = 50%
    DrawerSize.LARGE = 90%.

- style (dict; optional):
    CSS styles to apply to the dialog.

- title (a list of or a singular dash component, string or number; optional):
    Title of the dialog. If provided, an element with
    Classes.DIALOG_HEADER will be rendered inside the dialog before
    any children elements.

- transitionDuration (number; optional):
    Indicates how long (in milliseconds) the overlay's enter/leave
    transition takes. This is used by React CSSTransition  to know
    when a transition completes and must match the duration of the
    animation in CSS. Only set this prop if you  override Blueprint's
    default transitions with new transitions of a different length.

- transitionName (number; optional):
    Name of the transition for internal CSSTransition. Providing your
    own name here will require defining new CSS transition properties.

- usePortal (boolean; optional):
    Whether the overlay should be wrapped in a Portal, which renders
    its contents in a new element attached to portalContainer prop.
    This prop essentially determines which element is covered by the
    backdrop: if False, then only its parent is covered; otherwise,
    the entire page is  covered (because the parent of the Portal is
    the <body> itself). Set this prop to False on nested overlays
    (such as Drawer or Popover) to ensure that they are rendered above
    their parents."""
    _children_props = ['portalContainer', 'title']
    _base_nodes = ['portalContainer', 'title', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Drawer'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, autoFocus=Component.UNDEFINED, backdropClassName=Component.UNDEFINED, canEscapeKeyClose=Component.UNDEFINED, canOutsideClickClose=Component.UNDEFINED, className=Component.UNDEFINED, enforceFocus=Component.UNDEFINED, hasBackdrop=Component.UNDEFINED, icon=Component.UNDEFINED, isCloseButtonShown=Component.UNDEFINED, isOpen=Component.UNDEFINED, lazy=Component.UNDEFINED, portalClassName=Component.UNDEFINED, portalContainer=Component.UNDEFINED, position=Component.UNDEFINED, shouldReturnFocusOnClose=Component.UNDEFINED, size=Component.UNDEFINED, style=Component.UNDEFINED, title=Component.UNDEFINED, transitionDuration=Component.UNDEFINED, transitionName=Component.UNDEFINED, usePortal=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'autoFocus', 'backdropClassName', 'canEscapeKeyClose', 'canOutsideClickClose', 'className', 'enforceFocus', 'hasBackdrop', 'icon', 'isCloseButtonShown', 'isOpen', 'lazy', 'portalClassName', 'portalContainer', 'position', 'shouldReturnFocusOnClose', 'size', 'style', 'title', 'transitionDuration', 'transitionName', 'usePortal']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'autoFocus', 'backdropClassName', 'canEscapeKeyClose', 'canOutsideClickClose', 'className', 'enforceFocus', 'hasBackdrop', 'icon', 'isCloseButtonShown', 'isOpen', 'lazy', 'portalClassName', 'portalContainer', 'position', 'shouldReturnFocusOnClose', 'size', 'style', 'title', 'transitionDuration', 'transitionName', 'usePortal']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Drawer, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class InputGroup(Component):
    """An InputGroup component.
Input groups are a basic building block used to render text inputs across many Blueprint components. 
This component allows you to optionally add icons and buttons within a text input to expand its appearance 
and functionality. For example, you might use an input group to build a visibility toggle for a password field.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- addOnBlur (boolean; default False):
    If True, onAdd will be invoked when the input loses focus.
    Otherwise, onAdd  is only invoked when enter is pressed.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- defaultValue (string | number; optional):
    In uncontrolled mode, this sets the default value of the input.
    Note that this value is  only used upon component instantiation
    and changes to this prop during the component  lifecycle will be
    ignored.

- disabled (boolean; optional):
    Whether the input is non-interactive.

- fill (boolean; optional):
    Whether the component should take up the full width of its
    container.

- inputClassName (string; optional):
    Class name to apply to the <input> element (not the InputGroup
    container).

- intent (string; optional):
    Visual intent color to apply to element.

- large (boolean; optional):
    If set to True, the input will display with larger styling. This
    is equivalent to setting  Classes.LARGE via className on the
    parent control group and on the child input group.

- leftElement (a list of or a singular dash component, string or number; optional):
    Element to render on the left side of input. This prop is mutually
    exclusive with leftIcon.

- leftIcon (string; optional):
    Name of a Blueprint UI icon to render on the left side of the
    input group, before the user's cursor.

- placeholder (string; optional):
    Placeholder text in the absence of any value.

- rightElement (a list of or a singular dash component, string or number; optional):
    Element to render on right side of input. For best results, use a
    minimal button, tag, or small spinner.

- round (boolean; optional):
    Whether the input (and any buttons) should appear with rounded
    caps.

- small (boolean; optional):
    Whether the file input should appear with small styling.

- style (dict; optional):
    CSS properties to apply to the root element.

- text (string; optional):
    Input text updated when input loses blur or on 'Enter' key press.

- type (string; optional):
    HTML input type attribute.

- value (string; optional):
    Input value that changes every time a new character is inserted."""
    _children_props = ['leftElement', 'rightElement']
    _base_nodes = ['leftElement', 'rightElement', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'InputGroup'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, addOnBlur=Component.UNDEFINED, className=Component.UNDEFINED, defaultValue=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, inputClassName=Component.UNDEFINED, intent=Component.UNDEFINED, large=Component.UNDEFINED, leftElement=Component.UNDEFINED, leftIcon=Component.UNDEFINED, placeholder=Component.UNDEFINED, round=Component.UNDEFINED, rightElement=Component.UNDEFINED, small=Component.UNDEFINED, type=Component.UNDEFINED, value=Component.UNDEFINED, style=Component.UNDEFINED, text=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'addOnBlur', 'className', 'defaultValue', 'disabled', 'fill', 'inputClassName', 'intent', 'large', 'leftElement', 'leftIcon', 'placeholder', 'rightElement', 'round', 'small', 'style', 'text', 'type', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'addOnBlur', 'className', 'defaultValue', 'disabled', 'fill', 'inputClassName', 'intent', 'large', 'leftElement', 'leftIcon', 'placeholder', 'rightElement', 'round', 'small', 'style', 'text', 'type', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(InputGroup, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Breadcrumb(Component):
    """A Breadcrumb component.
Breadcrumbs identify the path to the current resource in an application.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- alwaysRenderOverflow (boolean; optional):
    Whether to display all the collapsed items or just the last one.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- collapseFrom (string; optional):
    Which direction the breadcrumbs should collapse from: start or
    end.

- items (list; optional):
    All breadcrumbs to display. Breadcrumbs that do not fit  in the
    container will be rendered in an overflow menu instead.

- minVisibleItems (number; optional):
    The minimum number of visible breadcrumbs that should never
    collapse into the overflow menu, regardless of DOM dimensions.

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Breadcrumb'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, alwaysRenderOverflow=Component.UNDEFINED, className=Component.UNDEFINED, collapseFrom=Component.UNDEFINED, items=Component.UNDEFINED, minVisibleItems=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'alwaysRenderOverflow', 'className', 'collapseFrom', 'items', 'minVisibleItems', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'alwaysRenderOverflow', 'className', 'collapseFrom', 'items', 'minVisibleItems', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Breadcrumb, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class NumericInput(Component):
    """A NumericInput component.
The NumericInput component provides controls for easily inputting, incrementing, and decrementing numeric values.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- addOnBlur (boolean; default False):
    If True, onAdd will be invoked when the input loses focus.
    Otherwise, onAdd  is only invoked when enter is pressed.

- allowNumericCharactersOnly (boolean; optional):
    Whether to allow only floating-point number characters in the
    field,  mimicking the native input[type=\"number\"].

- buttonPosition (a value equal to: 'left', 'right'; optional):
    The position of the buttons with respect to the input field.
    Either 'left' or 'right'.

- clampValueOnBlur (boolean; optional):
    Whether the value should be clamped to [min, max] on blur. The
    value will be clamped  to each bound only if the bound is defined.
    Note that native input[type=\"number\"] controls  do NOT clamp on
    blur.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- defaultValue (a value equal to: PropTypes.string, PropTypes.number; optional):
    In uncontrolled mode, this sets the default value of the input.
    Note that this value is  only used upon component instantiation
    and changes to this prop during the component  lifecycle will be
    ignored.

- disabled (boolean; optional):
    Whether the input is non-interactive.

- fill (boolean; optional):
    Whether the component should take up the full width of its
    container.

- inputClassName (string; optional):
    Class name to apply to the <input> element (not the InputGroup
    container).

- intent (string; optional):
    Visual intent color to apply to element.

- large (boolean; optional):
    If set to True, the input will display with larger styling. This
    is equivalent to setting  Classes.LARGE via className on the
    parent control group and on the child input group.

- leftElement (a list of or a singular dash component, string or number; optional):
    Element to render on the left side of input. This prop is mutually
    exclusive with leftIcon.

- leftIcon (string; optional):
    Name of a Blueprint UI icon to render on the left side of the
    input group, before the user's cursor. This prop is mutually
    exclusive with leftElement.

- locale (string; optional):
    The locale name, which is passed to the component to format the
    number and allowing to type the number  in the specific locale.
    See MDN documentation for more info about browser locale
    identification.

- majorStepSize (number; optional):
    The increment between successive values when shift is held. Pass
    explicit None value to disable this interaction.

- max (number; optional):
    The maximum value of the input. WARNING: This prop cannot be
    modified dynamically using callbacks.

- min (number; optional):
    The minimum value of the input. WARNING: This prop cannot be
    modified dynamically using callbacks.

- minorStepSize (number; optional):
    The increment between successive values when alt is held. Pass
    explicit None value to disable this interaction.

- number (string; optional):
    Input text updated when input loses blur or on 'Enter' key press.

- placeholder (string; optional):
    Placeholder text in the absence of any value.

- selectAllOnFocus (boolean; optional):
    Whether the entire text field should be selected on focus.

- selectAllOnIncrement (boolean; optional):
    Whether the entire text field should be selected on increment.

- small (boolean; optional):
    Whether the file input should appear with small styling.

- stepSize (number; optional):
    The increment between successive values when no modifier keys are
    held.

- style (dict; optional):
    CSS properties to apply to the root element.

- value (string; optional):
    Input value that changes every time a new character is inserted."""
    _children_props = ['leftElement']
    _base_nodes = ['leftElement', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'NumericInput'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, addOnBlur=Component.UNDEFINED, allowNumericCharactersOnly=Component.UNDEFINED, buttonPosition=Component.UNDEFINED, clampValueOnBlur=Component.UNDEFINED, className=Component.UNDEFINED, defaultValue=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, inputClassName=Component.UNDEFINED, intent=Component.UNDEFINED, large=Component.UNDEFINED, leftElement=Component.UNDEFINED, leftIcon=Component.UNDEFINED, locale=Component.UNDEFINED, majorStepSize=Component.UNDEFINED, max=Component.UNDEFINED, min=Component.UNDEFINED, minorStepSize=Component.UNDEFINED, placeholder=Component.UNDEFINED, selectAllOnFocus=Component.UNDEFINED, selectAllOnIncrement=Component.UNDEFINED, small=Component.UNDEFINED, stepSize=Component.UNDEFINED, style=Component.UNDEFINED, value=Component.UNDEFINED, number=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'addOnBlur', 'allowNumericCharactersOnly', 'buttonPosition', 'clampValueOnBlur', 'className', 'defaultValue', 'disabled', 'fill', 'inputClassName', 'intent', 'large', 'leftElement', 'leftIcon', 'locale', 'majorStepSize', 'max', 'min', 'minorStepSize', 'number', 'placeholder', 'selectAllOnFocus', 'selectAllOnIncrement', 'small', 'stepSize', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'addOnBlur', 'allowNumericCharactersOnly', 'buttonPosition', 'clampValueOnBlur', 'className', 'defaultValue', 'disabled', 'fill', 'inputClassName', 'intent', 'large', 'leftElement', 'leftIcon', 'locale', 'majorStepSize', 'max', 'min', 'minorStepSize', 'number', 'placeholder', 'selectAllOnFocus', 'selectAllOnIncrement', 'small', 'stepSize', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(NumericInput, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Spinner(Component):
    """A Spinner component.
Spinners indicate progress in a circular fashion. They're great for ongoing operations and 
can also represent known progress.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- intent (string; optional):
    Visual intent color to apply to element.

- size (number; optional):
    Width and height of the spinner in pixels. The size cannot be less
    than 10px.

- style (dict; optional):
    CSS properties to apply to the root element.

- tagName (optional):
    HTML tag for the two wrapper elements. If rendering a <Spinner>
    inside an <svg>,  change this to an SVG element like \"g\".

- value (number; optional):
    A value between 0 and 1 (inclusive) representing how far along the
    operation is.  Values below 0 or above 1 will be interpreted as 0
    or 1 respectively. Omitting  this prop will result in an
    \"indeterminate\" spinner where the head spins indefinitely."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Spinner'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, intent=Component.UNDEFINED, size=Component.UNDEFINED, tagName=Component.UNDEFINED, value=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'intent', 'size', 'style', 'tagName', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'intent', 'size', 'style', 'tagName', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Spinner, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Text(Component):
    """A Text component.
The Text component adds accessible overflow behavior to a line of text by conditionally 
adding the title attribute and truncating with an ellipsis when content overflows its container.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Content of Text.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- ellipsize (boolean; optional):
    Indicates that this component should be truncated with an ellipsis
    if it  overflows its container. The title attribute will also be
    added when content  overflows to show the full text of the
    children on hover.

- style (dict; optional):
    CSS properties to apply to the root element.

- tagName (optional):
    HTML tag name to use for rendered element.

- title (string; optional):
    HTML title of the element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Text'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, ellipsize=Component.UNDEFINED, style=Component.UNDEFINED, tagName=Component.UNDEFINED, title=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'ellipsize', 'style', 'tagName', 'title']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'ellipsize', 'style', 'tagName', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Text, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Divider(Component):
    """A Divider component.
Divider visually separate contents with a thin line and margin on all sides. Dividers work best 
in flex layouts where they will adapt to orientation without additional styles. Otherwise, a 
divider will appear as a full-width 1px-high block element.

Keyword arguments:

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- style (dict; optional):
    CSS properties to apply to the root element.

- tagName (optional):
    HTML tag to use for element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Divider'
    @_explicitize_args
    def __init__(self, className=Component.UNDEFINED, style=Component.UNDEFINED, tagName=Component.UNDEFINED, **kwargs):
        self._prop_names = ['className', 'style', 'tagName']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['className', 'style', 'tagName']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Divider, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DateInput(Component):
    """A DateInput component.
The DateInput component is an InputGroup that shows a DatePicker inside a Popover on focus. 
It optionally shows a TimezoneSelect on the right side of the InputGroup, allowing the user 
to change the timezone of the selected date.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- canClearSelection (boolean; optional):
    Allows the user to clear the selection by clicking the currently
    selected day. Passed to DatePicker component.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- clearButtonText (string; optional):
    Text for the reset button in the date picker action bar. Passed to
    DatePicker component.

- closeOnSelection (string; optional):
    Whether the calendar popover should close when a date is selected.

- date (string; optional):
    An ISO string representing the selected time.

- dateFnsFormat (string; optional):
    date-fns format string used to format & parse date strings.

- defaultTimezone (string; optional):
    The default timezone selected. Defaults to the user local
    timezone.

- defaultValue (string; optional):
    The default date to be used in the component when uncontrolled,
    represented as an ISO string.

- disableTimezoneSelect (boolean; optional):
    Whether to disable the timezone select.

- disabled (boolean; optional):
    Whether the date input is non-interactive.

- fill (boolean; optional):
    Whether the component should take up the full width of its
    container.

- footerElement (a list of or a singular dash component, string or number; optional):
    An additional element to show below the date picker.

- highlightCurrentDay (boolean; optional):
    Whether the current day should be highlighted in the calendar.

- initialMonth (string; optional):
    The initial month the calendar displays.

- invalidDateMessage (string; optional):
    The error message to display when the date selected is invalid.

- locale (string; optional):
    date-fns Locale object or locale code string ((ISO 639-1 +
    optional country code) which  will be used to localize the date
    picker. If you provide a locale code string and receive  a loading
    error, please make sure it is included in the list of date-fns'.

- maxDate (string; optional):
    The latest date the user can select.

- minDate (string; optional):
    The earliest date the user can select.

- outOfRangeMessage (string; optional):
    The error message to display when the date selected is out of
    range.

- placeholder (string; optional):
    Placeholder text to display in empty input fields. Recommended
    practice is to indicate the expected date format.

- reverseMonthAndYearMenus (boolean; optional):
    If True, the month menu will appear to the left of the year menu.
    Otherwise, the month menu will apear to  the right of the year
    menu.

- rightElement (a list of or a singular dash component, string or number; optional):
    Element to render on right side of input.

- selectedShortcutIndex (number; optional):
    The currently selected shortcut. If this prop is provided, the
    component acts in a controlled manner.

- shortcuts (boolean; optional):
    Whether shortcuts to quickly select a date are displayed or not.
    If True, preset shortcuts will be displayed. If False,  no
    shortcuts will be displayed.

- showActionsBar (boolean; optional):
    Whether the bottom bar displaying \"Today\" and \"Clear\" buttons
    should be shown.

- showTimeArrowButtons (boolean; optional):
    Whether arrows for selecting the time should be shown.

- showTimezoneSelect (boolean; optional):
    Whether to show the timezone select dropdown on the right side of
    the input. If timePrecision is undefined, this will always be
    False.

- style (dict; optional):
    CSS properties to apply to the root element.

- timePrecision (string; optional):
    The precision of time selection that accompanies the calendar.
    Passing a TimePrecision value shows a TimePicker below the
    calendar. Time is preserved across date changes. Either 'minute',
    'second', 'millisecond'.

- todayButtonText (string; optional):
    Text for the today button in the action bar.

- useAmPm (boolean; optional):
    Whether the time should be displayed as AM/PM."""
    _children_props = ['footerElement', 'rightElement']
    _base_nodes = ['footerElement', 'rightElement', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'DateInput'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, canClearSelection=Component.UNDEFINED, className=Component.UNDEFINED, clearButtonText=Component.UNDEFINED, closeOnSelection=Component.UNDEFINED, date=Component.UNDEFINED, dateFnsFormat=Component.UNDEFINED, defaultTimezone=Component.UNDEFINED, defaultValue=Component.UNDEFINED, disabled=Component.UNDEFINED, disableTimezoneSelect=Component.UNDEFINED, fill=Component.UNDEFINED, footerElement=Component.UNDEFINED, highlightCurrentDay=Component.UNDEFINED, initialMonth=Component.UNDEFINED, invalidDateMessage=Component.UNDEFINED, locale=Component.UNDEFINED, maxDate=Component.UNDEFINED, minDate=Component.UNDEFINED, outOfRangeMessage=Component.UNDEFINED, placeholder=Component.UNDEFINED, reverseMonthAndYearMenus=Component.UNDEFINED, rightElement=Component.UNDEFINED, selectedShortcutIndex=Component.UNDEFINED, shortcuts=Component.UNDEFINED, showActionsBar=Component.UNDEFINED, showTimezoneSelect=Component.UNDEFINED, showTimeArrowButtons=Component.UNDEFINED, style=Component.UNDEFINED, timePrecision=Component.UNDEFINED, todayButtonText=Component.UNDEFINED, useAmPm=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'canClearSelection', 'className', 'clearButtonText', 'closeOnSelection', 'date', 'dateFnsFormat', 'defaultTimezone', 'defaultValue', 'disableTimezoneSelect', 'disabled', 'fill', 'footerElement', 'highlightCurrentDay', 'initialMonth', 'invalidDateMessage', 'locale', 'maxDate', 'minDate', 'outOfRangeMessage', 'placeholder', 'reverseMonthAndYearMenus', 'rightElement', 'selectedShortcutIndex', 'shortcuts', 'showActionsBar', 'showTimeArrowButtons', 'showTimezoneSelect', 'style', 'timePrecision', 'todayButtonText', 'useAmPm']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'canClearSelection', 'className', 'clearButtonText', 'closeOnSelection', 'date', 'dateFnsFormat', 'defaultTimezone', 'defaultValue', 'disableTimezoneSelect', 'disabled', 'fill', 'footerElement', 'highlightCurrentDay', 'initialMonth', 'invalidDateMessage', 'locale', 'maxDate', 'minDate', 'outOfRangeMessage', 'placeholder', 'reverseMonthAndYearMenus', 'rightElement', 'selectedShortcutIndex', 'shortcuts', 'showActionsBar', 'showTimeArrowButtons', 'showTimezoneSelect', 'style', 'timePrecision', 'todayButtonText', 'useAmPm']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(DateInput, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class EntityTitle(Component):
    """An EntityTitle component.
EntityTitle is a component that handles rendering a common UI pattern consisting of title, icon, subtitle and tag.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- ellipsize (boolean; optional):
    Whether the overflowing text content should be ellipsized.

- heading (a value equal to: 'Text', 'H1', 'H2', 'H3', 'H4', 'H5', 'H6'; default 'Text'):
    React component to render the main title heading. This defaults to
    Blueprint's <Text> component, * which inherits font size from its
    containing element(s).

- icon (string; optional):
    Name of a Blueprint UI icon (or an icon element) to render in the
    section's header.  Note that the header will only be rendered if
    title is provided.

- loading (boolean; optional):
    Whether to render as loading state.

- style (dict; optional):
    CSS properties to apply to the root element.

- subtitle (a list of or a singular dash component, string or number; optional):
    The content to render below the title. Defaults to render muted
    text.

- tags (a list of or a singular dash component, string or number; optional):
    tags to be added on the right of the element.

- title (a list of or a singular dash component, string or number; required):
    The primary title to render.

- titleURL (string; optional):
    If specified, the title will be wrapped in an anchor with this
    URL."""
    _children_props = ['subtitle', 'tags', 'title']
    _base_nodes = ['subtitle', 'tags', 'title', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'EntityTitle'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, ellipsize=Component.UNDEFINED, heading=Component.UNDEFINED, icon=Component.UNDEFINED, loading=Component.UNDEFINED, subtitle=Component.UNDEFINED, style=Component.UNDEFINED, tags=Component.UNDEFINED, title=Component.REQUIRED, titleURL=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'ellipsize', 'heading', 'icon', 'loading', 'style', 'subtitle', 'tags', 'title', 'titleURL']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'ellipsize', 'heading', 'icon', 'loading', 'style', 'subtitle', 'tags', 'title', 'titleURL']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['title']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(EntityTitle, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Alert(Component):
    """An Alert component.
Alerts notify users of important information and force them to acknowledge the alert content before continuing.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Dialog contents.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- canEscapeKeyCancel (boolean; optional):
    Whether pressing escape when focused on the Alert should cancel
    the alert. If  this prop is enabled, then either onCancel or
    onClose must also be defined.

- canOutsideClickCancel (boolean; optional):
    Whether clicking outside the Alert should cancel the alert. If
    this prop is enabled,  then either onCancel or onClose must also
    be defined.

- cancelButtonText (string; optional):
    The text for the cancel button. If this prop is defined, then
    either  onCancel or onClose must also be defined.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- confirmButtonText (string; optional):
    The text for the confirm (right-most) button. This button will
    always appear,  and uses the value of the intent prop below.

- fill (boolean; optional):
    Whether the component should take up the full width of its
    container.

- icon (string; optional):
    Name of a Blueprint UI icon to display on the left side.

- intent (string; optional):
    The intent to be applied to the confirm (right-most) button and
    the icon (if provided).

- isCanceled (boolean; optional):
    Value set when the user cancel the alert.

- isClosed (boolean; optional):
    Value set when the user either confirm or cancel the alert.

- isConfirmed (boolean; optional):
    Value set when the user confirm the alert.

- isOpen (boolean; default False):
    Toggles the visibility of the alert.

- loading (boolean; optional):
    If set to True, the confirm button will be set to its loading
    state. The cancel button,  if visible, will be disabled.

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Alert'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, cancelButtonText=Component.UNDEFINED, canEscapeKeyCancel=Component.UNDEFINED, canOutsideClickCancel=Component.UNDEFINED, className=Component.UNDEFINED, confirmButtonText=Component.UNDEFINED, icon=Component.UNDEFINED, fill=Component.UNDEFINED, intent=Component.UNDEFINED, isOpen=Component.UNDEFINED, loading=Component.UNDEFINED, isCanceled=Component.UNDEFINED, isConfirmed=Component.UNDEFINED, isClosed=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'canEscapeKeyCancel', 'canOutsideClickCancel', 'cancelButtonText', 'className', 'confirmButtonText', 'fill', 'icon', 'intent', 'isCanceled', 'isClosed', 'isConfirmed', 'isOpen', 'loading', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'canEscapeKeyCancel', 'canOutsideClickCancel', 'cancelButtonText', 'className', 'confirmButtonText', 'fill', 'icon', 'intent', 'isCanceled', 'isClosed', 'isConfirmed', 'isOpen', 'loading', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Alert, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class HTMLSelect(Component):
    """A HTMLSelect component.
Styling HTML <select> tags requires a wrapper element to customize the dropdown caret, 
so Blueprint provides a HTMLSelect component to streamline this process.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Radio elements. This prop is mutually exclusive with options.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- disabled (boolean; optional):
    Whether this element is non-interactive.

- fill (boolean; optional):
    Whether this element should fill its container.

- iconName (string; default "double-caret-vertical"):
    Name of one of the supported icons for this component to display
    on the right side of the element.

- large (boolean; optional):
    Whether to use large styles.

- minimal (boolean; optional):
    Whether to use minimal styles.

- options (list; optional):
    Shorthand for supplying options: an array of { label?, value }
    objects. If no label is supplied,  value will be used as the
    label.

- style (dict; optional):
    CSS properties to apply to the root element.

- value (a value equal to: PropTypes.number, PropTypes.string; optional):
    Controlled value of this component."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'HTMLSelect'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, disabled=Component.UNDEFINED, fill=Component.UNDEFINED, iconName=Component.UNDEFINED, large=Component.UNDEFINED, minimal=Component.UNDEFINED, options=Component.UNDEFINED, value=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'disabled', 'fill', 'iconName', 'large', 'minimal', 'options', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'disabled', 'fill', 'iconName', 'large', 'minimal', 'options', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(HTMLSelect, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class MenuItem(Component):
    """A MenuItem component.
A MenuItem is a single interactive item in a Menu.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Children of this component will be rendered in a submenu that
    appears  in a popover when hovering or clicking on this item. Use
    text prop for the content of the menu item itself.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- active (boolean; optional):
    Whether this item should appear active, often useful to  indicate
    keyboard focus. Note that this is distinct from selected
    appearance, which has its own prop.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- disabled (boolean; optional):
    Whether this menu item is non-interactive. Enabling this prop will
    ignore href, tabIndex, and mouse event handlers (in particular
    click, down,  enter, leave).

- href (string; optional):
    Link URL.

- htmlTitle (string; optional):
    HTML title to be passed to the component.

- icon (string; optional):
    Name of a Blueprint UI icon (or an icon element) to render before
    the text.

- intent (string; optional):
    Visual intent color to apply to element.

- label (string; optional):
    Right-aligned label text content, useful for displaying hotkeys.
    This prop  actually supports JSX elements, but TypeScript will
    throw an error because  HTMLAttributes only allows strings. Use
    labelElement to supply a JSX element  in TypeScript.

- labelClassName (string; optional):
    A space-delimited list of class names to pass along to the
    right-aligned  label wrapper element.

- labelElement (a list of or a singular dash component, string or number; optional):
    Right-aligned label content, useful for displaying hotkeys.

- multiline (boolean; optional):
    Whether the text should be allowed to wrap to multiple lines. If
    False,  text will be truncated with an ellipsis when it reaches
    max-width.

- n_clicks (number; default 0):
    An integer that represents the time (in ms since 1970) at which
    n_clicks changed. This can be used to tell which button was
    changed most recently.

- roleStructure (a value equal to: 'menuitem', 'listoption', 'listitem', 'none'; optional):
    Changes the ARIA role property structure of this MenuItem to
    accomodate for  various different roles of the parent Menu ul
    element. If menuitem, role structure becomes: <li role=\"none\" <a
    role=\"menuitem\" which is proper role structure for a <ul
    role=\"menu\" parent (this is the  default role of a Menu). If
    listoption, role structure becomes: <li role=\"option\" <a
    role=undefined which is proper role structure for a <ul
    role=\"listbox\" parent, or  a <select> parent.

- selected (boolean; optional):
    Whether this item should appear selected. Defining this will set
    the  aria-selected attribute and apply a \"check\" or \"blank\"
    icon on the  item (unless the icon prop is set, which always takes
    precedence).

- shouldDismissPopover (boolean; optional):
    Whether an enabled item without a submenu should automatically
    close  its parent popover when clicked.

- style (dict; optional):
    CSS properties to apply to the root element.

- tagName (optional):
    Name of the HTML tag that wraps the MenuItem.

- target (string; optional):
    Link target attribute. Use \"_blank\" to open in a new window.

- text (a list of or a singular dash component, string or number; optional):
    Item text, required for usability.

- textClassName (string; optional):
    A space-delimited list of class names to pass along to the text
    wrapper element."""
    _children_props = ['labelElement', 'text']
    _base_nodes = ['labelElement', 'text', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'MenuItem'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, active=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, href=Component.UNDEFINED, htmlTitle=Component.UNDEFINED, icon=Component.UNDEFINED, intent=Component.UNDEFINED, label=Component.UNDEFINED, labelClassName=Component.UNDEFINED, labelElement=Component.UNDEFINED, multiline=Component.UNDEFINED, n_clicks=Component.UNDEFINED, roleStructure=Component.UNDEFINED, selected=Component.UNDEFINED, shouldDismissPopover=Component.UNDEFINED, style=Component.UNDEFINED, tagName=Component.UNDEFINED, target=Component.UNDEFINED, text=Component.UNDEFINED, textClassName=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'active', 'className', 'disabled', 'href', 'htmlTitle', 'icon', 'intent', 'label', 'labelClassName', 'labelElement', 'multiline', 'n_clicks', 'roleStructure', 'selected', 'shouldDismissPopover', 'style', 'tagName', 'target', 'text', 'textClassName']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'active', 'className', 'disabled', 'href', 'htmlTitle', 'icon', 'intent', 'label', 'labelClassName', 'labelElement', 'multiline', 'n_clicks', 'roleStructure', 'selected', 'shouldDismissPopover', 'style', 'tagName', 'target', 'text', 'textClassName']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(MenuItem, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Card(Component):
    """A Card component.
A card is a bounded unit of UI content with a solid background color.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    card content.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- compact (boolean; optional):
    Whether this component should use compact styles with reduced
    visual padding.

- elevation (number; default 0):
    Controls the intensity of the drop shadow beneath the card: the
    higher  the elevation, the higher the drop shadow. At elevation 0,
    no drop  shadow is applied.

- interactive (boolean; optional):
    Whether the card should respond to user interactions. If set to
    True,  hovering over the card will increase the card's elevation
    and change  the mouse cursor to a pointer.

- n_clicks (number; default 0):
    An integer that represents the time (in ms since 1970) at which
    n_clicks changed. This can be used to tell which button was
    changed most recently.

- style (dict; optional):
    CSS styles to apply to the card."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Card'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, compact=Component.UNDEFINED, elevation=Component.UNDEFINED, interactive=Component.UNDEFINED, n_clicks=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'compact', 'elevation', 'interactive', 'n_clicks', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'compact', 'elevation', 'interactive', 'n_clicks', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Card, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DialogFooter(Component):
    """A DialogFooter component.
Footer of the dialog. Footer "actions" are rendered towards the right side of the footer container element.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Child contents are rendered on the left side of the footer.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- actions (a list of or a singular dash component, string or number; optional):
    Dialog actions (typically buttons) are rendered on the right side
    of the footer.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- minimal (boolean; optional):
    Use a \"minimal\" appearance for the footer, simply applying an
    HTML role and some visual padding. This is useful for small
    dialogs,  and should not be used with <DialogBody
    useOverflowScrollContainer>. Note that this is the default
    behavior when using the CSS API, since that's how the
    -dialog-footer class was first introduced,  so these styles are
    applied without a \"modifier\" class. When using the JS component
    API, minimal is False by default. Show the footer close from the
    content. Do not use with scroll body Use for small dialogs
    (confirm).

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = ['actions']
    _base_nodes = ['actions', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'DialogFooter'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, actions=Component.UNDEFINED, className=Component.UNDEFINED, minimal=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'actions', 'className', 'minimal', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'actions', 'className', 'minimal', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(DialogFooter, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Callout(Component):
    """A Callout component.
Callouts visually highlight important content for the user. They can contain a title, an icon and content. 
Each intent has a default icon associated with it.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Buttons in this group.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- icon (string; optional):
    Name of a Blueprint UI icon (or an icon element) to render on the
    left side.  If this prop is omitted or undefined, the intent prop
    will determine  a default icon. If this prop is explicitly None,
    no icon will be displayed  (regardless of intent).

- intent (string; optional):
    Visual intent color to apply to background, title, and icon.
    Defining this  prop also applies a default icon, if the icon prop
    is omitted.

- style (dict; optional):
    CSS properties to apply to the root element.

- title (string; optional):
    String content of optional title element. Due to a conflict with
    the HTML prop  types, to provide JSX content simply pass <H4>JSX
    title content</H4> as first  children element instead of using
    this prop (note uppercase tag name to use  the Blueprint Heading
    component)."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'Callout'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, icon=Component.UNDEFINED, intent=Component.UNDEFINED, style=Component.UNDEFINED, title=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'icon', 'intent', 'style', 'title']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'icon', 'intent', 'style', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Callout, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class TreeNode(Component):
    """A TreeNode component.
TreeNode elements determine the contents, appearance, and state of each node in the tree.

Keyword arguments:

- id (string | number; optional):
    A unique identifier for the node.

- childNodes (list; optional):
    Child tree nodes of this node.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- disabled (boolean; optional):
    Whether this tree node is non-interactive. Enabling this prop will
    ignore mouse event handlers  (in particular click, down, enter,
    leave).

- hasCaret (boolean; optional):
    Whether the caret to expand/collapse a node should be shown. If
    not specified, this will  be True if the node has children and
    False otherwise.

- icon (string; optional):
    The name of a Blueprint icon (or an icon element) to render next
    to the node's label.

- isExpanded (boolean; optional):
    Whether this node is expanded.

- isSelected (boolean; optional):
    Whether this node is selected.

- key (string; optional):
    Insert.

- label (string; optional):
    The main label for the node.

- secondaryLabel (string; optional):
    A secondary label/component that is displayed at the right side of
    the node.

- style (dict; optional):
    CSS properties to apply to the root element."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_blueprint_components'
    _type = 'TreeNode'
    @_explicitize_args
    def __init__(self, className=Component.UNDEFINED, childNodes=Component.UNDEFINED, disabled=Component.UNDEFINED, hasCaret=Component.UNDEFINED, icon=Component.UNDEFINED, id=Component.UNDEFINED, isExpanded=Component.UNDEFINED, isSelected=Component.UNDEFINED, key=Component.UNDEFINED, label=Component.UNDEFINED, secondaryLabel=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'childNodes', 'className', 'disabled', 'hasCaret', 'icon', 'isExpanded', 'isSelected', 'key', 'label', 'secondaryLabel', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'childNodes', 'className', 'disabled', 'hasCaret', 'icon', 'isExpanded', 'isSelected', 'key', 'label', 'secondaryLabel', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(TreeNode, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Section(Component):
    """A Section component.
The Section component can be used to contain, structure, and create hierarchy for information in your UI.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Section Cards.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    A space-delimited list of class names to pass along to a child
    element.

- collapsible (boolean; optional):
    Whether this section's contents should be collapsible.

- compact (boolean; optional):
    Whether this section should use compact styles.

- defaultIsOpen (boolean; optional):
    When collapsible, whether the default should be open.

- elevation (number; optional):
    Visual elevation of this container element.

- icon (string; optional):
    Name of a Blueprint UI icon (or an icon element) to render in the
    section's header. Note that the header will only be rendered if
    title is provided.

- rightElement (a list of or a singular dash component, string or number; optional):
    Element to render on the right side of the section header. Note
    that the header will  only be rendered if title is provided.

- style (dict; optional):
    CSS properties to apply to the root element.

- subtitle (string | a list of or a singular dash component, string or number; optional):
    Sub-title of the section. Note that the header will only be
    rendered if title is provided.

- title (string | a list of or a singular dash component, string or number; optional):
    Title of the section. Note that the header will only be rendered
    if title is provided."""
    _children_props = ['rightElement', 'subtitle', 'title']
    _base_nodes = ['rightElement', 'subtitle', 'title', 'children']
    _namespace = 'dash_blueprint_components'
    _type = 'Section'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, collapsible=Component.UNDEFINED, compact=Component.UNDEFINED, elevation=Component.UNDEFINED, defaultIsOpen=Component.UNDEFINED, icon=Component.UNDEFINED, rightElement=Component.UNDEFINED, subtitle=Component.UNDEFINED, style=Component.UNDEFINED, title=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'collapsible', 'compact', 'defaultIsOpen', 'elevation', 'icon', 'rightElement', 'style', 'subtitle', 'title']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'collapsible', 'compact', 'defaultIsOpen', 'elevation', 'icon', 'rightElement', 'style', 'subtitle', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Section, self).__init__(children=children, **args)
